==> slony1-2_2.2.4.orig.tar.bz2: slony1-2.2.4/src/slony_logshipper/y.tab.h <==
/* A Bison parser, made by GNU Bison 2.5.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     K_LOGFILE = 258,
     K_MAX = 259,
     K_ARCHIVES = 260,
     K_ANALYZE = 261,
     K_AND = 262,
     K_ARCHIVE = 263,
     K_ARCHIVE_COMMENT = 264,
     K_CASCADE = 265,
     K_CLUSTER = 266,
     K_COMMAND = 267,
     K_COMMIT = 268,
     K_CONF_COMMENT = 269,
     K_COPY = 270,
     K_DATABASE = 271,
     K_DELETE = 272,
     K_DESTINATION = 273,
     K_DIR = 274,
     K_ERROR = 275,
     K_EXEC_DDL = 276,
     K_FROM = 277,
     K_IGNORE = 278,
     K_INSERT = 279,
     K_INTO = 280,
     K_NAME = 281,
     K_NAMESPACE = 282,
     K_NULL = 283,
     K_ONLY = 284,
     K_POST = 285,
     K_PRE = 286,
     K_PROCESSING = 287,
     K_RENAME = 288,
     K_REPLICA = 289,
     K_SELECT = 290,
     K_SESSION_ROLE = 291,
     K_SET = 292,
     K_START = 293,
     K_START_ARCHIVE = 294,
     K_START_CONFIG = 295,
     K_TABLE = 296,
     K_TO = 297,
     K_TRANSACTION = 298,
     K_TRUNCATE = 299,
     K_UPDATE = 300,
     K_VACUUM = 301,
     K_VALUES = 302,
     K_WHERE = 303,
     T_COPYDATA = 304,
     T_COPYDATA_PART = 305,
     T_COPYEND = 306,
     T_IDENT = 307,
     T_LITERAL = 308,
     T_LITERAL_PART = 309,
     T_NUMBER = 310,
     T_TRACKING_FUNCTION = 311,
     T_FINISH_FUNCTION = 312,
     T_SEQSETVAL_FUNCTION = 313,
     T_PGSETVAL_FUNCTION = 314
   };
#endif
/* Tokens.  */
#define K_LOGFILE 258
#define K_MAX 259
#define K_ARCHIVES 260
#define K_ANALYZE 261
#define K_AND 262
#define K_ARCHIVE 263
#define K_ARCHIVE_COMMENT 264
#define K_CASCADE 265
#define K_CLUSTER 266
#define K_COMMAND 267
#define K_COMMIT 268
#define K_CONF_COMMENT 269
#define K_COPY 270
#define K_DATABASE 271
#define K_DELETE 272
#define K_DESTINATION 273
#define K_DIR 274
#define K_ERROR 275
#define K_EXEC_DDL 276
#define K_FROM 277
#define K_IGNORE 278
#define K_INSERT 279
#define K_INTO 280
#define K_NAME 281
#define K_NAMESPACE 282
#define K_NULL 283
#define K_ONLY 284
#define K_POST 285
#define K_PRE 286
#define K_PROCESSING 287
#define K_RENAME 288
#define K_REPLICA 289
#define K_SELECT 290
#define K_SESSION_ROLE 291
#define K_SET 292
#define K_START 293
#define K_START_ARCHIVE 294
#define K_START_CONFIG 295
#define K_TABLE 296
#define K_TO 297
#define K_TRANSACTION 298
#define K_TRUNCATE 299
#define K_UPDATE 300
#define K_VACUUM 301
#define K_VALUES 302
#define K_WHERE 303
#define T_COPYDATA 304
#define T_COPYDATA_PART 305
#define T_COPYEND 306
#define T_IDENT 307
#define T_LITERAL 308
#define T_LITERAL_PART 309
#define T_NUMBER 310
#define T_TRACKING_FUNCTION 311
#define T_FINISH_FUNCTION 312
#define T_SEQSETVAL_FUNCTION 313
#define T_PGSETVAL_FUNCTION 314




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 2068 of yacc.c  */
#line 38 "parser.y"

	int32		ival;
	char	   *str;
	AttElem	   *att_elem;
	AttElemList	*att_elem_list;
	SlonDString *dstring;



/* Line 2068 of yacc.c  */
#line 178 "y.tab.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE yylval;

==> slony1-2_2.2.8.orig.tar.bz2: slony1-2.2.8/src/slony_logshipper/y.tab.h <==
/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_YY_Y_TAB_H_INCLUDED
# define YY_YY_Y_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    K_LOGFILE = 258,
    K_MAX = 259,
    K_ARCHIVES = 260,
    K_ANALYZE = 261,
    K_AND = 262,
    K_ARCHIVE = 263,
    K_ARCHIVE_COMMENT = 264,
    K_CASCADE = 265,
    K_CLUSTER = 266,
    K_COMMAND = 267,
    K_COMMIT = 268,
    K_CONF_COMMENT = 269,
    K_COPY = 270,
    K_DATABASE = 271,
    K_DELETE = 272,
    K_DESTINATION = 273,
    K_DIR = 274,
    K_ERROR = 275,
    K_EXEC_DDL = 276,
    K_FROM = 277,
    K_IGNORE = 278,
    K_INSERT = 279,
    K_INTO = 280,
    K_NAME = 281,
    K_NAMESPACE = 282,
    K_NULL = 283,
    K_ONLY = 284,
    K_POST = 285,
    K_PRE = 286,
    K_PROCESSING = 287,
    K_RENAME = 288,
    K_REPLICA = 289,
    K_SELECT = 290,
    K_SESSION_ROLE = 291,
    K_SET = 292,
    K_START = 293,
    K_START_ARCHIVE = 294,
    K_START_CONFIG = 295,
    K_TABLE = 296,
    K_TO = 297,
    K_TRANSACTION = 298,
    K_TRUNCATE = 299,
    K_UPDATE = 300,
    K_VACUUM = 301,
    K_VALUES = 302,
    K_WHERE = 303,
    T_COPYDATA = 304,
    T_COPYDATA_PART = 305,
    T_COPYEND = 306,
    T_IDENT = 307,
    T_LITERAL = 308,
    T_LITERAL_PART = 309,
    T_NUMBER = 310,
    T_TRACKING_FUNCTION = 311,
    T_FINISH_FUNCTION = 312,
    T_SEQSETVAL_FUNCTION = 313,
    T_PGSETVAL_FUNCTION = 314
  };
#endif
/* Tokens.  */
#define K_LOGFILE 258
#define K_MAX 259
#define K_ARCHIVES 260
#define K_ANALYZE 261
#define K_AND 262
#define K_ARCHIVE 263
#define K_ARCHIVE_COMMENT 264
#define K_CASCADE 265
#define K_CLUSTER 266
#define K_COMMAND 267
#define K_COMMIT 268
#define K_CONF_COMMENT 269
#define K_COPY 270
#define K_DATABASE 271
#define K_DELETE 272
#define K_DESTINATION 273
#define K_DIR 274
#define K_ERROR 275
#define K_EXEC_DDL 276
#define K_FROM 277
#define K_IGNORE 278
#define K_INSERT 279
#define K_INTO 280
#define K_NAME 281
#define K_NAMESPACE 282
#define K_NULL 283
#define K_ONLY 284
#define K_POST 285
#define K_PRE 286
#define K_PROCESSING 287
#define K_RENAME 288
#define K_REPLICA 289
#define K_SELECT 290
#define K_SESSION_ROLE 291
#define K_SET 292
#define K_START 293
#define K_START_ARCHIVE 294
#define K_START_CONFIG 295
#define K_TABLE 296
#define K_TO 297
#define K_TRANSACTION 298
#define K_TRUNCATE 299
#define K_UPDATE 300
#define K_VACUUM 301
#define K_VALUES 302
#define K_WHERE 303
#define T_COPYDATA 304
#define T_COPYDATA_PART 305
#define T_COPYEND 306
#define T_IDENT 307
#define T_LITERAL 308
#define T_LITERAL_PART 309
#define T_NUMBER 310
#define T_TRACKING_FUNCTION 311
#define T_FINISH_FUNCTION 312
#define T_SEQSETVAL_FUNCTION 313
#define T_PGSETVAL_FUNCTION 314

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE YYSTYPE;
union YYSTYPE
{
#line 38 "parser.y" /* yacc.c:1909  */

	int32		ival;
	char	   *str;
	AttElem	   *att_elem;
	AttElemList	*att_elem_list;
	SlonDString *dstring;

#line 180 "y.tab.h" /* yacc.c:1909  */
};
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;

int yyparse (void);

#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
